import Sheet from '@mui/joy/Sheet';
import Typography from '@mui/joy/Typography';
import FormControl from '@mui/joy/FormControl';
import FormLabel from '@mui/joy/FormLabel';
import Input from '@mui/joy/Input';
import Button from '@mui/joy/Button';
import Link from '@mui/joy/Link';
import Box from '@mui/joy/Box';
import Divider from '@mui/joy/Divider';
import Stack from '@mui/joy/Stack';
import Checkbox from '@mui/joy/Checkbox';
import { GoogleIcon } from '@rakit/joy-ui';

export function SignInCard() {
  return (
    <Sheet
      sx={{
        width: 400,
        mx: 'auto', // margin left & right
        my: 4, // margin top & bottom
        py: 3, // padding top & bottom
        px: 4, // padding left & right
        display: 'flex',
        flexDirection: 'column',
        gap: 2,
        borderRadius: 'sm',
        boxShadow: 'md',
      }}
      variant="outlined"
    >
      <Box
        component="main"
        sx={{
          my: 'auto',
          py: 2,
          pb: 5,
          display: 'flex',
          flexDirection: 'column',
          gap: 2,
          width: 360,
          maxWidth: '100%',
          mx: 'auto',
          borderRadius: 'sm',
          '& form': {
            display: 'flex',
            flexDirection: 'column',
            gap: 2,
          },
          [`& .MuiFormLabel-asterisk`]: {
            visibility: 'hidden',
          },
        }}
      >
        <Stack sx={{ gap: 4, mb: 2 }}>
          <Stack sx={{ gap: 1 }}>
            <Typography component="h1" level="h3">
              Sign in
            </Typography>
            <Typography level="body-sm">
              New to company?{' '}
              <Link href="#replace-with-a-link" level="title-sm">
                Sign up!
              </Link>
            </Typography>
          </Stack>
          <Button
            variant="soft"
            color="neutral"
            fullWidth
            startDecorator={<GoogleIcon />}
          >
            Continue with Google
          </Button>
        </Stack>
        <Divider
          sx={(theme) => ({
            [theme.getColorSchemeSelector('light')]: {
              color: { xs: '#FFF', md: 'text.tertiary' },
            },
          })}
        >
          或者
        </Divider>
        <Stack sx={{ gap: 4, mt: 2 }}>
          <form
            onSubmit={(event: React.FormEvent<SignInFormElement>) => {
              event.preventDefault();
              const formElements = event.currentTarget.elements;
              const data = {
                email: formElements.email.value,
                password: formElements.password.value,
                persistent: formElements.persistent.checked,
              };
              alert(JSON.stringify(data, null, 2));
            }}
          >
            <FormControl required>
              <FormLabel>您的账户</FormLabel>
              <Input type="text" name="account" placeholder="用户名/手机/邮箱" />
            </FormControl>
            <FormControl required>
              <FormLabel>登录密码</FormLabel>
              <Input type="password" name="password" placeholder="至少6位" />
            </FormControl>
            <Stack sx={{ gap: 4, mt: 2 }}>
              <Box
                sx={{
                  display: 'flex',
                  justifyContent: 'space-between',
                  alignItems: 'center',
                }}
              >
                <Checkbox size="sm" label="记住我" name="persistent" />
                <Link level="title-sm" href="#replace-with-a-link">
                  忘记了密码？
                </Link>
              </Box>
              <Button type="submit" fullWidth>
                登录
              </Button>
            </Stack>
          </form>
        </Stack>
      </Box>
    </Sheet>
  );
}
