import { ReactNode } from 'react';
import {
  useInRouterContext,
  createHashRouter,
  RouterProvider,
} from 'react-router-dom';
import { BasenameContextProvider } from './BasenameContextProvider';

export interface AppRouterProps {
  basename?: string;
  children: React.ReactNode;
}

/**
 * Creates a react-router Router unless the app is already inside existing router.
 * Also creates a BasenameContext with the basename prop
 */
export const AppRouter = ({ basename = '', children }: AppRouterProps) => {
  const isInRouter = useInRouterContext();
  const Router = isInRouter ? DummyRouter : InternalRouter;

  return (
    <BasenameContextProvider basename={isInRouter ? basename : ''}>
      <Router basename={basename}>{children}</Router>
    </BasenameContextProvider>
  );
};

const DummyRouter = ({
  children,
}: {
  children: ReactNode;
  basename?: string;
}) => <>{children}</>;

const InternalRouter = ({
  children,
  basename,
}: {
  children: ReactNode;
  basename?: string;
}) => {
  const router = createHashRouter(
    [{ path: '*', element: <>{children}</> }],
    { basename },
  );
  return <RouterProvider router={router} />;
};
